@@ -63,8 +63,17 @@ func Start(buildInfo *BuildInfo, integrationTest integrationTypes.IntegrationTes
 			log.Fatal(absRepoPath + " is not a valid git repository.")
 		}
 
-		cliArgs.WorkTree = absRepoPath
 		cliArgs.GitDir = filepath.Join(absRepoPath, ".git")
+		err = os.Chdir(absRepoPath)
+		if err != nil {
+			log.Fatalf("Failed to change directory to %s: %v", absRepoPath, err)
+		}
+	} else if cliArgs.WorkTree != "" {
+		env.SetWorkTreeEnv(cliArgs.WorkTree)
+
+		if err := os.Chdir(cliArgs.WorkTree); err != nil {
+			log.Fatalf("Failed to change directory to %s: %v", cliArgs.WorkTree, err)
+		}
 	}
 
 	if cliArgs.CustomConfigFile != "" {
@@ -75,13 +84,6 @@ func Start(buildInfo *BuildInfo, integrationTest integrationTypes.IntegrationTes
 		os.Setenv("CONFIG_DIR", cliArgs.UseConfigDir)
 	}
 
-	if cliArgs.WorkTree != "" {
-		err := os.Chdir(cliArgs.WorkTree)
-		if err != nil {
-			log.Fatalf("Failed to change directory to %s: %v", cliArgs.WorkTree, err)
-		}
-	}
-
 	if cliArgs.GitDir != "" {
 		env.SetGitDirEnv(cliArgs.GitDir)
 	}
@@ -118,12 +120,6 @@ func Start(buildInfo *BuildInfo, integrationTest integrationTypes.IntegrationTes
 		os.Exit(0)
 	}
 
-	if cliArgs.WorkTree != "" {
-		if err := os.Chdir(cliArgs.WorkTree); err != nil {
-			log.Fatal(err.Error())
-		}
-	}
-
 	tempDir, err := os.MkdirTemp("", "lazygit-*")
 	if err != nil {
 		log.Fatal(err.Error())
