@@ -1,6 +1,8 @@
 package git_commands
 
-import "strings"
+import (
+	"strings"
+)
 
 // convenience struct for building git commands. Especially useful when
 // including conditional args
@@ -42,9 +44,34 @@ func (self *GitCommandBuilder) Config(value string) *GitCommandBuilder {
 	return self
 }
 
-func (self *GitCommandBuilder) RepoPath(value string) *GitCommandBuilder {
+// the -C arg will make git do a `cd` to the directory before doing anything else
+func (self *GitCommandBuilder) Dir(path string) *GitCommandBuilder {
 	// repo path comes before the command
-	self.args = append([]string{"-C", value}, self.args...)
+	self.args = append([]string{"-C", path}, self.args...)
+
+	return self
+}
+
+// Note, you may prefer to use the Dir method instead of this one
+func (self *GitCommandBuilder) Worktree(path string) *GitCommandBuilder {
+	// worktree arg comes before the command
+	self.args = append([]string{"--work-tree", path}, self.args...)
+
+	return self
+}
+
+// Note, you may prefer to use the Dir method instead of this one
+func (self *GitCommandBuilder) GitDir(path string) *GitCommandBuilder {
+	// git dir arg comes before the command
+	self.args = append([]string{"--git-dir", path}, self.args...)
+
+	return self
+}
+
+func (self *GitCommandBuilder) GitDirIf(condition bool, path string) *GitCommandBuilder {
+	if condition {
+		return self.GitDir(path)
+	}
 
 	return self
 }
