@@ -1,6 +1,7 @@
 package git_commands
 
 import (
+	"os"
 	"path/filepath"
 	"strconv"
 	"strings"
@@ -24,14 +25,14 @@ func NewStatusCommands(
 // RebaseMode returns "" for non-rebase mode, "normal" for normal rebase
 // and "interactive" for interactive rebase
 func (self *StatusCommands) RebaseMode() (enums.RebaseMode, error) {
-	exists, err := self.os.FileExists(filepath.Join(self.dotGitDir, "rebase-apply"))
+	exists, err := self.os.FileExists(filepath.Join(self.repoPaths.WorktreeGitDirPath(), "rebase-apply"))
 	if err != nil {
 		return enums.REBASE_MODE_NONE, err
 	}
 	if exists {
 		return enums.REBASE_MODE_NORMAL, nil
 	}
-	exists, err = self.os.FileExists(filepath.Join(self.dotGitDir, "rebase-merge"))
+	exists, err = self.os.FileExists(filepath.Join(self.repoPaths.WorktreeGitDirPath(), "rebase-merge"))
 	if exists {
 		return enums.REBASE_MODE_INTERACTIVE, err
 	} else {
@@ -69,5 +70,16 @@ func IsBareRepo(osCommand *oscommands.OSCommand) (bool, error) {
 
 // IsInMergeState states whether we are still mid-merge
 func (self *StatusCommands) IsInMergeState() (bool, error) {
-	return self.os.FileExists(filepath.Join(self.dotGitDir, "MERGE_HEAD"))
+	return self.os.FileExists(filepath.Join(self.repoPaths.WorktreeGitDirPath(), "MERGE_HEAD"))
+}
+
+// Full ref (e.g. "refs/heads/mybranch") of the branch that is currently
+// being rebased, or empty string when we're not in a rebase
+func (self *StatusCommands) BranchBeingRebased() string {
+	for _, dir := range []string{"rebase-merge", "rebase-apply"} {
+		if bytesContent, err := os.ReadFile(filepath.Join(self.repoPaths.WorktreeGitDirPath(), dir, "head-name")); err == nil {
+			return strings.TrimSpace(string(bytesContent))
+		}
+	}
+	return ""
 }
