@@ -27,45 +27,51 @@ type RefresherConfig struct {
 }
 
 type GuiConfig struct {
-	AuthorColors                map[string]string  `yaml:"authorColors"`
-	BranchColors                map[string]string  `yaml:"branchColors"`
-	ScrollHeight                int                `yaml:"scrollHeight"`
-	ScrollPastBottom            bool               `yaml:"scrollPastBottom"`
-	MouseEvents                 bool               `yaml:"mouseEvents"`
-	SkipUnstageLineWarning      bool               `yaml:"skipUnstageLineWarning"`
-	SkipStashWarning            bool               `yaml:"skipStashWarning"`
-	SidePanelWidth              float64            `yaml:"sidePanelWidth"`
-	ExpandFocusedSidePanel      bool               `yaml:"expandFocusedSidePanel"`
-	MainPanelSplitMode          string             `yaml:"mainPanelSplitMode"`
-	Language                    string             `yaml:"language"`
-	TimeFormat                  string             `yaml:"timeFormat"`
-	Theme                       ThemeConfig        `yaml:"theme"`
-	CommitLength                CommitLengthConfig `yaml:"commitLength"`
-	SkipNoStagedFilesWarning    bool               `yaml:"skipNoStagedFilesWarning"`
-	ShowListFooter              bool               `yaml:"showListFooter"`
-	ShowFileTree                bool               `yaml:"showFileTree"`
-	ShowRandomTip               bool               `yaml:"showRandomTip"`
-	ShowCommandLog              bool               `yaml:"showCommandLog"`
-	ShowBottomLine              bool               `yaml:"showBottomLine"`
-	ShowIcons                   bool               `yaml:"showIcons"`
-	ExperimentalShowBranchHeads bool               `yaml:"experimentalShowBranchHeads"`
-	CommandLogSize              int                `yaml:"commandLogSize"`
-	SplitDiff                   string             `yaml:"splitDiff"`
-	SkipRewordInEditorWarning   bool               `yaml:"skipRewordInEditorWarning"`
-	WindowSize                  string             `yaml:"windowSize"`
-	Border                      string             `yaml:"border"`
+	AuthorColors              map[string]string  `yaml:"authorColors"`
+	BranchColors              map[string]string  `yaml:"branchColors"`
+	ScrollHeight              int                `yaml:"scrollHeight"`
+	ScrollPastBottom          bool               `yaml:"scrollPastBottom"`
+	MouseEvents               bool               `yaml:"mouseEvents"`
+	SkipDiscardChangeWarning  bool               `yaml:"skipDiscardChangeWarning"`
+	SkipStashWarning          bool               `yaml:"skipStashWarning"`
+	SidePanelWidth            float64            `yaml:"sidePanelWidth"`
+	ExpandFocusedSidePanel    bool               `yaml:"expandFocusedSidePanel"`
+	MainPanelSplitMode        string             `yaml:"mainPanelSplitMode"`
+	Language                  string             `yaml:"language"`
+	TimeFormat                string             `yaml:"timeFormat"`
+	ShortTimeFormat           string             `yaml:"shortTimeFormat"`
+	Theme                     ThemeConfig        `yaml:"theme"`
+	CommitLength              CommitLengthConfig `yaml:"commitLength"`
+	SkipNoStagedFilesWarning  bool               `yaml:"skipNoStagedFilesWarning"`
+	ShowListFooter            bool               `yaml:"showListFooter"`
+	ShowFileTree              bool               `yaml:"showFileTree"`
+	ShowRandomTip             bool               `yaml:"showRandomTip"`
+	ShowCommandLog            bool               `yaml:"showCommandLog"`
+	ShowBottomLine            bool               `yaml:"showBottomLine"`
+	ShowIcons                 bool               `yaml:"showIcons"`
+	NerdFontsVersion          string             `yaml:"nerdFontsVersion"`
+	ShowBranchCommitHash      bool               `yaml:"showBranchCommitHash"`
+	CommandLogSize            int                `yaml:"commandLogSize"`
+	SplitDiff                 string             `yaml:"splitDiff"`
+	SkipRewordInEditorWarning bool               `yaml:"skipRewordInEditorWarning"`
+	WindowSize                string             `yaml:"windowSize"`
+	Border                    string             `yaml:"border"`
+	AnimateExplosion          bool               `yaml:"animateExplosion"`
 }
 
 type ThemeConfig struct {
-	ActiveBorderColor         []string `yaml:"activeBorderColor"`
-	InactiveBorderColor       []string `yaml:"inactiveBorderColor"`
-	OptionsTextColor          []string `yaml:"optionsTextColor"`
-	SelectedLineBgColor       []string `yaml:"selectedLineBgColor"`
-	SelectedRangeBgColor      []string `yaml:"selectedRangeBgColor"`
-	CherryPickedCommitBgColor []string `yaml:"cherryPickedCommitBgColor"`
-	CherryPickedCommitFgColor []string `yaml:"cherryPickedCommitFgColor"`
-	UnstagedChangesColor      []string `yaml:"unstagedChangesColor"`
-	DefaultFgColor            []string `yaml:"defaultFgColor"`
+	ActiveBorderColor          []string `yaml:"activeBorderColor"`
+	InactiveBorderColor        []string `yaml:"inactiveBorderColor"`
+	SearchingActiveBorderColor []string `yaml:"searchingActiveBorderColor"`
+	OptionsTextColor           []string `yaml:"optionsTextColor"`
+	SelectedLineBgColor        []string `yaml:"selectedLineBgColor"`
+	SelectedRangeBgColor       []string `yaml:"selectedRangeBgColor"`
+	CherryPickedCommitBgColor  []string `yaml:"cherryPickedCommitBgColor"`
+	CherryPickedCommitFgColor  []string `yaml:"cherryPickedCommitFgColor"`
+	MarkedBaseCommitBgColor    []string `yaml:"markedBaseCommitBgColor"`
+	MarkedBaseCommitFgColor    []string `yaml:"markedBaseCommitFgColor"`
+	UnstagedChangesColor       []string `yaml:"unstagedChangesColor"`
+	DefaultFgColor             []string `yaml:"defaultFgColor"`
 }
 
 type CommitLengthConfig struct {
@@ -76,9 +82,11 @@ type GitConfig struct {
 	Paging              PagingConfig                  `yaml:"paging"`
 	Commit              CommitConfig                  `yaml:"commit"`
 	Merging             MergingConfig                 `yaml:"merging"`
+	MainBranches        []string                      `yaml:"mainBranches"`
 	SkipHookPrefix      string                        `yaml:"skipHookPrefix"`
 	AutoFetch           bool                          `yaml:"autoFetch"`
 	AutoRefresh         bool                          `yaml:"autoRefresh"`
+	FetchAll            bool                          `yaml:"fetchAll"`
 	BranchLogCmd        string                        `yaml:"branchLogCmd"`
 	AllBranchesLogCmd   string                        `yaml:"allBranchesLogCmd"`
 	OverrideGpg         bool                          `yaml:"overrideGpg"`
@@ -97,8 +105,7 @@ type PagingConfig struct {
 }
 
 type CommitConfig struct {
-	SignOff bool   `yaml:"signOff"`
-	Verbose string `yaml:"verbose"`
+	SignOff bool `yaml:"signOff"`
 }
 
 type MergingConfig struct {
@@ -127,6 +134,7 @@ type KeybindingConfig struct {
 	Status      KeybindingStatusConfig      `yaml:"status"`
 	Files       KeybindingFilesConfig       `yaml:"files"`
 	Branches    KeybindingBranchesConfig    `yaml:"branches"`
+	Worktrees   KeybindingWorktreesConfig   `yaml:"worktrees"`
 	Commits     KeybindingCommitsConfig     `yaml:"commits"`
 	Stash       KeybindingStashConfig       `yaml:"stash"`
 	CommitFiles KeybindingCommitFilesConfig `yaml:"commitFiles"`
@@ -241,6 +249,10 @@ type KeybindingBranchesConfig struct {
 	FetchRemote            string `yaml:"fetchRemote"`
 }
 
+type KeybindingWorktreesConfig struct {
+	ViewWorktreeOptions string `yaml:"viewWorktreeOptions"`
+}
+
 type KeybindingCommitsConfig struct {
 	SquashDown                     string `yaml:"squashDown"`
 	RenameCommit                   string `yaml:"renameCommit"`
@@ -258,6 +270,7 @@ type KeybindingCommitsConfig struct {
 	CherryPickCopy                 string `yaml:"cherryPickCopy"`
 	CherryPickCopyRange            string `yaml:"cherryPickCopyRange"`
 	PasteCommits                   string `yaml:"pasteCommits"`
+	MarkCommitAsBaseForRebase      string `yaml:"markCommitAsBaseForRebase"`
 	CreateTag                      string `yaml:"tagCommit"`
 	CheckoutCommit                 string `yaml:"checkoutCommit"`
 	ResetCherryPick                string `yaml:"resetCherryPick"`
@@ -308,6 +321,9 @@ type OSConfig struct {
 	// Pointer to bool so that we can distinguish unset (nil) from false.
 	EditInTerminal *bool `yaml:"editInTerminal,omitempty"`
 
+	// For opening a directory in an editor
+	OpenDirInEditor string `yaml:"openDirInEditor,omitempty"`
+
 	// A built-in preset that sets all of the above settings. Supported presets
 	// are defined in the getPreset function in editor_presets.go.
 	EditPreset string `yaml:"editPreset,omitempty"`
@@ -341,30 +357,37 @@ type OSConfig struct {
 	// OpenLinkCommand is the command for opening a link
 	// Deprecated: use OpenLink instead.
 	OpenLinkCommand string `yaml:"openLinkCommand,omitempty"`
+
+	// CopyToClipboardCmd is the command for copying to clipboard
+	CopyToClipboardCmd string `yaml:"copyToClipboardCmd,omitempty"`
+}
+
+type CustomCommandAfterHook struct {
+	CheckForConflicts bool `yaml:"checkForConflicts"`
 }
 
 type CustomCommand struct {
-	Key         string                `yaml:"key"`
-	Context     string                `yaml:"context"`
-	Command     string                `yaml:"command"`
-	Subprocess  bool                  `yaml:"subprocess"`
-	Prompts     []CustomCommandPrompt `yaml:"prompts"`
-	LoadingText string                `yaml:"loadingText"`
-	Description string                `yaml:"description"`
-	Stream      bool                  `yaml:"stream"`
-	ShowOutput  bool                  `yaml:"showOutput"`
+	Key         string                 `yaml:"key"`
+	Context     string                 `yaml:"context"`
+	Command     string                 `yaml:"command"`
+	Subprocess  bool                   `yaml:"subprocess"`
+	Prompts     []CustomCommandPrompt  `yaml:"prompts"`
+	LoadingText string                 `yaml:"loadingText"`
+	Description string                 `yaml:"description"`
+	Stream      bool                   `yaml:"stream"`
+	ShowOutput  bool                   `yaml:"showOutput"`
+	After       CustomCommandAfterHook `yaml:"after"`
 }
 
 type CustomCommandPrompt struct {
-	Key string `yaml:"key"`
-
 	// one of 'input', 'menu', 'confirm', or 'menuFromCommand'
-	Type string `yaml:"type"`
-
+	Type  string `yaml:"type"`
+	Key   string `yaml:"key"`
 	Title string `yaml:"title"`
 
-	// this only apply to input prompts
-	InitialValue string `yaml:"initialValue"`
+	// these only apply to input prompts
+	InitialValue string                   `yaml:"initialValue"`
+	Suggestions  CustomCommandSuggestions `yaml:"suggestions"`
 
 	// this only applies to confirm prompts
 	Body string `yaml:"body"`
@@ -379,6 +402,11 @@ type CustomCommandPrompt struct {
 	LabelFormat string `yaml:"labelFormat"`
 }
 
+type CustomCommandSuggestions struct {
+	Preset  string `yaml:"preset"`
+	Command string `yaml:"command"`
+}
+
 type CustomCommandMenuOption struct {
 	Name        string `yaml:"name"`
 	Description string `yaml:"description"`
@@ -388,40 +416,46 @@ type CustomCommandMenuOption struct {
 func GetDefaultConfig() *UserConfig {
 	return &UserConfig{
 		Gui: GuiConfig{
-			ScrollHeight:           2,
-			ScrollPastBottom:       true,
-			MouseEvents:            true,
-			SkipUnstageLineWarning: false,
-			SkipStashWarning:       false,
-			SidePanelWidth:         0.3333,
-			ExpandFocusedSidePanel: false,
-			MainPanelSplitMode:     "flexible",
-			Language:               "auto",
-			TimeFormat:             time.RFC822,
+			ScrollHeight:             2,
+			ScrollPastBottom:         true,
+			MouseEvents:              true,
+			SkipDiscardChangeWarning: false,
+			SkipStashWarning:         false,
+			SidePanelWidth:           0.3333,
+			ExpandFocusedSidePanel:   false,
+			MainPanelSplitMode:       "flexible",
+			Language:                 "auto",
+			TimeFormat:               "02 Jan 06",
+			ShortTimeFormat:          time.Kitchen,
 			Theme: ThemeConfig{
-				ActiveBorderColor:         []string{"green", "bold"},
-				InactiveBorderColor:       []string{"default"},
-				OptionsTextColor:          []string{"blue"},
-				SelectedLineBgColor:       []string{"blue"},
-				SelectedRangeBgColor:      []string{"blue"},
-				CherryPickedCommitBgColor: []string{"cyan"},
-				CherryPickedCommitFgColor: []string{"blue"},
-				UnstagedChangesColor:      []string{"red"},
-				DefaultFgColor:            []string{"default"},
+				ActiveBorderColor:          []string{"green", "bold"},
+				SearchingActiveBorderColor: []string{"cyan", "bold"},
+				InactiveBorderColor:        []string{"default"},
+				OptionsTextColor:           []string{"blue"},
+				SelectedLineBgColor:        []string{"blue"},
+				SelectedRangeBgColor:       []string{"blue"},
+				CherryPickedCommitBgColor:  []string{"cyan"},
+				CherryPickedCommitFgColor:  []string{"blue"},
+				MarkedBaseCommitBgColor:    []string{"yellow"},
+				MarkedBaseCommitFgColor:    []string{"blue"},
+				UnstagedChangesColor:       []string{"red"},
+				DefaultFgColor:             []string{"default"},
 			},
-			CommitLength:                CommitLengthConfig{Show: true},
-			SkipNoStagedFilesWarning:    false,
-			ShowListFooter:              true,
-			ShowCommandLog:              true,
-			ShowBottomLine:              true,
-			ShowFileTree:                true,
-			ShowRandomTip:               true,
-			ShowIcons:                   false,
-			ExperimentalShowBranchHeads: false,
-			CommandLogSize:              8,
-			SplitDiff:                   "auto",
-			SkipRewordInEditorWarning:   false,
-			Border:                      "single",
+			CommitLength:              CommitLengthConfig{Show: true},
+			SkipNoStagedFilesWarning:  false,
+			ShowListFooter:            true,
+			ShowCommandLog:            true,
+			ShowBottomLine:            true,
+			ShowFileTree:              true,
+			ShowRandomTip:             true,
+			ShowIcons:                 false,
+			NerdFontsVersion:          "",
+			ShowBranchCommitHash:      false,
+			CommandLogSize:            8,
+			SplitDiff:                 "auto",
+			SkipRewordInEditorWarning: false,
+			Border:                    "single",
+			AnimateExplosion:          true,
 		},
 		Git: GitConfig{
 			Paging: PagingConfig{
@@ -431,7 +465,6 @@ func GetDefaultConfig() *UserConfig {
 			},
 			Commit: CommitConfig{
 				SignOff: false,
-				Verbose: "default",
 			},
 			Merging: MergingConfig{
 				ManualCommit: false,
@@ -443,8 +476,10 @@ func GetDefaultConfig() *UserConfig {
 				ShowWholeGraph: false,
 			},
 			SkipHookPrefix:      "WIP",
+			MainBranches:        []string{"master", "main"},
 			AutoFetch:           true,
 			AutoRefresh:         true,
+			FetchAll:            true,
 			BranchLogCmd:        "git log --graph --color=always --abbrev-commit --decorate --date=relative --pretty=medium {{branchName}} --",
 			AllBranchesLogCmd:   "git log --graph --all --color=always --abbrev-commit --decorate --date=relative  --pretty=medium",
 			DisableForcePushing: false,
@@ -565,6 +600,9 @@ func GetDefaultConfig() *UserConfig {
 				SetUpstream:            "u",
 				FetchRemote:            "f",
 			},
+			Worktrees: KeybindingWorktreesConfig{
+				ViewWorktreeOptions: "w",
+			},
 			Commits: KeybindingCommitsConfig{
 				SquashDown:                     "s",
 				RenameCommit:                   "r",
@@ -582,6 +620,7 @@ func GetDefaultConfig() *UserConfig {
 				CherryPickCopy:                 "c",
 				CherryPickCopyRange:            "C",
 				PasteCommits:                   "v",
+				MarkCommitAsBaseForRebase:      "B",
 				CreateTag:                      "T",
 				CheckoutCommit:                 "<space>",
 				ResetCherryPick:                "<c-R>",
