@@ -4,14 +4,13 @@ import (
 	"fmt"
 	"strings"
 
-	"github.com/jesseduffield/generics/slices"
-	"github.com/jesseduffield/lazygit/pkg/commands"
+	"github.com/jesseduffield/gocui"
 	"github.com/jesseduffield/lazygit/pkg/commands/git_commands"
 	"github.com/jesseduffield/lazygit/pkg/commands/models"
-	"github.com/jesseduffield/lazygit/pkg/gui/context"
 	"github.com/jesseduffield/lazygit/pkg/gui/style"
 	"github.com/jesseduffield/lazygit/pkg/gui/types"
 	"github.com/jesseduffield/lazygit/pkg/utils"
+	"github.com/samber/lo"
 )
 
 type IRefsHelper interface {
@@ -23,23 +22,14 @@ type IRefsHelper interface {
 }
 
 type RefsHelper struct {
-	c        *types.HelperCommon
-	git      *commands.GitCommand
-	contexts *context.ContextTree
-	model    *types.Model
+	c *HelperCommon
 }
 
 func NewRefsHelper(
-	c *types.HelperCommon,
-	git *commands.GitCommand,
-	contexts *context.ContextTree,
-	model *types.Model,
+	c *HelperCommon,
 ) *RefsHelper {
 	return &RefsHelper{
-		c:        c,
-		git:      git,
-		contexts: contexts,
-		model:    model,
+		c: c,
 	}
 }
 
@@ -54,15 +44,15 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 	cmdOptions := git_commands.CheckoutOptions{Force: false, EnvVars: options.EnvVars}
 
 	onSuccess := func() {
-		self.contexts.Branches.SetSelectedLineIdx(0)
-		self.contexts.ReflogCommits.SetSelectedLineIdx(0)
-		self.contexts.LocalCommits.SetSelectedLineIdx(0)
+		self.c.Contexts().Branches.SetSelectedLineIdx(0)
+		self.c.Contexts().ReflogCommits.SetSelectedLineIdx(0)
+		self.c.Contexts().LocalCommits.SetSelectedLineIdx(0)
 		// loading a heap of commits is slow so we limit them whenever doing a reset
-		self.contexts.LocalCommits.SetLimitCommits(true)
+		self.c.Contexts().LocalCommits.SetLimitCommits(true)
 	}
 
-	return self.c.WithWaitingStatus(waitingStatus, func() error {
-		if err := self.git.Branch.Checkout(ref, cmdOptions); err != nil {
+	return self.c.WithWaitingStatus(waitingStatus, func(gocui.Task) error {
+		if err := self.c.Git().Branch.Checkout(ref, cmdOptions); err != nil {
 			// note, this will only work for english-language git commands. If we force git to use english, and the error isn't this one, then the user will receive an english command they may not understand. I'm not sure what the best solution to this is. Running the command once in english and a second time in the native language is one option
 
 			if options.OnRefNotFound != nil && strings.Contains(err.Error(), "did not match any file(s) known to git") {
@@ -75,15 +65,15 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 					Title:  self.c.Tr.AutoStashTitle,
 					Prompt: self.c.Tr.AutoStashPrompt,
 					HandleConfirm: func() error {
-						if err := self.git.Stash.Save(self.c.Tr.StashPrefix + ref); err != nil {
+						if err := self.c.Git().Stash.Push(self.c.Tr.StashPrefix + ref); err != nil {
 							return self.c.Error(err)
 						}
-						if err := self.git.Branch.Checkout(ref, cmdOptions); err != nil {
+						if err := self.c.Git().Branch.Checkout(ref, cmdOptions); err != nil {
 							return self.c.Error(err)
 						}
 
 						onSuccess()
-						if err := self.git.Stash.Pop(0); err != nil {
+						if err := self.c.Git().Stash.Pop(0); err != nil {
 							if err := self.c.Refresh(types.RefreshOptions{Mode: types.BLOCK_UI}); err != nil {
 								return err
 							}
@@ -105,22 +95,22 @@ func (self *RefsHelper) CheckoutRef(ref string, options types.CheckoutRefOptions
 }
 
 func (self *RefsHelper) GetCheckedOutRef() *models.Branch {
-	if len(self.model.Branches) == 0 {
+	if len(self.c.Model().Branches) == 0 {
 		return nil
 	}
 
-	return self.model.Branches[0]
+	return self.c.Model().Branches[0]
 }
 
 func (self *RefsHelper) ResetToRef(ref string, strength string, envVars []string) error {
-	if err := self.git.Commit.ResetToCommit(ref, strength, envVars); err != nil {
+	if err := self.c.Git().Commit.ResetToCommit(ref, strength, envVars); err != nil {
 		return self.c.Error(err)
 	}
 
-	self.contexts.LocalCommits.SetSelectedLineIdx(0)
-	self.contexts.ReflogCommits.SetSelectedLineIdx(0)
+	self.c.Contexts().LocalCommits.SetSelectedLineIdx(0)
+	self.c.Contexts().ReflogCommits.SetSelectedLineIdx(0)
 	// loading a heap of commits is slow so we limit them whenever doing a reset
-	self.contexts.LocalCommits.SetLimitCommits(true)
+	self.c.Contexts().LocalCommits.SetLimitCommits(true)
 
 	if err := self.c.Refresh(types.RefreshOptions{Scope: []types.RefreshableView{types.FILES, types.BRANCHES, types.REFLOG, types.COMMITS}}); err != nil {
 		return err
@@ -132,18 +122,20 @@ func (self *RefsHelper) ResetToRef(ref string, strength string, envVars []string
 func (self *RefsHelper) CreateGitResetMenu(ref string) error {
 	type strengthWithKey struct {
 		strength string
+		label    string
 		key      types.Key
 	}
 	strengths := []strengthWithKey{
-		{strength: "soft", key: 's'},
-		{strength: "mixed", key: 'm'},
-		{strength: "hard", key: 'h'},
+		// not i18'ing because it's git terminology
+		{strength: "soft", label: "Soft reset", key: 's'},
+		{strength: "mixed", label: "Mixed reset", key: 'm'},
+		{strength: "hard", label: "Hard reset", key: 'h'},
 	}
 
-	menuItems := slices.Map(strengths, func(row strengthWithKey) *types.MenuItem {
+	menuItems := lo.Map(strengths, func(row strengthWithKey, _ int) *types.MenuItem {
 		return &types.MenuItem{
 			LabelColumns: []string{
-				fmt.Sprintf("%s reset", row.strength),
+				row.label,
 				style.FgRed.Sprintf("reset --%s %s", row.strength, ref),
 			},
 			OnPress: func() error {
@@ -155,7 +147,7 @@ func (self *RefsHelper) CreateGitResetMenu(ref string) error {
 	})
 
 	return self.c.Menu(types.CreateMenuOptions{
-		Title: fmt.Sprintf("%s %s", self.c.Tr.LcResetTo, ref),
+		Title: fmt.Sprintf("%s %s", self.c.Tr.ResetTo, ref),
 		Items: menuItems,
 	})
 }
@@ -173,18 +165,18 @@ func (self *RefsHelper) NewBranch(from string, fromFormattedName string, suggest
 		InitialContent: suggestedBranchName,
 		HandleConfirm: func(response string) error {
 			self.c.LogAction(self.c.Tr.Actions.CreateBranch)
-			if err := self.git.Branch.New(sanitizedBranchName(response), from); err != nil {
+			if err := self.c.Git().Branch.New(sanitizedBranchName(response), from); err != nil {
 				return err
 			}
 
-			if self.c.CurrentContext() != self.contexts.Branches {
-				if err := self.c.PushContext(self.contexts.Branches); err != nil {
+			if self.c.CurrentContext() != self.c.Contexts().Branches {
+				if err := self.c.PushContext(self.c.Contexts().Branches); err != nil {
 					return err
 				}
 			}
 
-			self.contexts.LocalCommits.SetSelectedLineIdx(0)
-			self.contexts.Branches.SetSelectedLineIdx(0)
+			self.c.Contexts().LocalCommits.SetSelectedLineIdx(0)
+			self.c.Contexts().Branches.SetSelectedLineIdx(0)
 
 			return self.c.Refresh(types.RefreshOptions{Mode: types.ASYNC})
 		},
