@@ -3,9 +3,7 @@ package utils
 import (
 	"encoding/json"
 	"fmt"
-	"log"
 	"os"
-	"path/filepath"
 	"regexp"
 	"runtime"
 	"strconv"
@@ -15,15 +13,6 @@ import (
 	"github.com/jesseduffield/gocui"
 )
 
-// GetCurrentRepoName gets the repo's base name
-func GetCurrentRepoName() string {
-	pwd, err := os.Getwd()
-	if err != nil {
-		log.Fatalln(err.Error())
-	}
-	return filepath.Base(pwd)
-}
-
 // GetProjectRoot returns the path to the root of the project. Only to be used
 // in testing contexts, as with binaries it's unlikely this path will exist on
 // the machine
@@ -75,6 +64,10 @@ func AsJson(i interface{}) string {
 
 // used to keep a number n between 0 and max, allowing for wraparounds
 func ModuloWithWrap(n, max int) int {
+	if max == 0 {
+		return 0
+	}
+
 	if n >= max {
 		return n % max
 	} else if n < 0 {
@@ -124,3 +117,10 @@ func StackTrace() string {
 	n := runtime.Stack(buf, false)
 	return fmt.Sprintf("%s\n", buf[:n])
 }
+
+// returns the path of the file that calls the function.
+// 'skip' is the number of stack frames to skip.
+func FilePath(skip int) string {
+	_, path, _, _ := runtime.Caller(skip)
+	return path
+}
